#!/bin/sh

apt-get update
apt-get upgrade -y
apt-get install -y \
	build-essential \
	curl \
	dbus \
	dbus-x11 \
	git \
	libcairo2-dev \
	libgirepository1.0-dev \
	libglib2.0-dev \
	libgtk-3-dev \
	libreadline-dev \
	libxml2 \
	libxml2-dev \
	nettle-dev \
	parallel \
	pkg-config \
	valgrind

VERSION=$(cat dist/version)

cp dist/tarot-$VERSION.tar.gz . || exit 1
tar xf tarot-$VERSION.tar.gz || exit 1
mkdir build || exit 1
cd build/
../tarot-$VERSION/configure \
    --enable-silent-rules=yes \
    --enable-valgrind=yes \
    || (cat config.log; exit 1)
make -j 16 || exit 1
make install || exit 1

export PATH="/usr/local/bin:$PATH"
export LD_LIBRARY_PATH="/usr/local/lib:$LD_LIBRARY_PATH"

mkdir /root/.ssh || exit 1
echo "$SSH_KEY" > /root/.ssh/id_rsa || exit 1
echo "$SSH_KEY_PUB" > /root/.ssh/id_rsa.pub || exit 1
echo "$SSH_KNOWN_HOSTS" > /root/.ssh/known_hosts || exit 1
chmod go-rwx /root/.ssh/id_rsa || exit 1
git config --global user.email "vivien@planete-kraus.eu" || exit 1
git config --global user.name "Gitlab CI for the tarot package" || exit 1
git clone git@framagit.org:play-tarot/datasets.git dataset/ || exit 1

rm -rf dataset/generated/mcts

mkdir -p dataset/generated/mcts || exit 1
mkdir -p dataset/generated/stacking || exit 1

seq 1 10 | parallel ../tarot-$VERSION/ci/generate-seed.sh {}
for check in /tmp/all-*-*-failed
do
    if test "x$(cat $check)" != "xno"
    then
	echo "Could not generate anything for test '$check'."
	exit 1
    fi
done

if test "x$CI_COMMIT_TAG" != "x" \
	|| test "x$CI_COMMIT_REF_NAME" = "xmaster" \
	|| test "x$CI_COMMIT_REF_NAME" = "xdevelop"
then
    cd dataset
    git checkout -b "update-generated-from-$VERSION" || exit 1
    if git add . && git commit -m"Add the generated datasets from version $VERSION"
    then
	git push origin "update-generated-from-$VERSION" || exit 1
    fi
    DATA=$(cat <<EOF
{
  "id": $CI_PROJECT_ID,
  "source_branch": "update-generated-from-$VERSION",
  "target_branch": "master",
  "title": "Update with the generated games for version $VERSION",
  "remove_source_branch": true
}
EOF
	   )
    curl \
	--request POST \
	--header "Content-Type: application/json" \
	--header "PRIVATE-TOKEN: $PRIVATE_TOKEN" \
	--data "$DATA" \
	"$CI_API_V4_URL/projects/46125/merge_requests" \
	|| exit 1
fi
