#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#include <tarot.h>
#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>

#ifndef LOCALEDIR
#define LOCALEDIR "/usr/share/locale"
#endif /* NOT LOCALEDIR */

int
main ()
{
  TarotCard card;
  TarotNumber number;
  TarotSuit suit;
  char *name;
  char *end;
  static const char *ks = "KS";
  if (tarot_init (LOCALEDIR) != 0)
    {
      fprintf (stderr, "Error: could not initialize libtarot.\n");
      return EXIT_FAILURE;
    }
  if (tarot_of (TAROT_KING, TAROT_SPADES, &card) != 0)
    {
      fprintf (stderr, "Computing the king of spades failed.\n");
      return EXIT_FAILURE;
    }
  if (tarot_decompose (card, &number, &suit) != 0)
    {
      fprintf (stderr, "Could not decompose the king of spades.\n");
      return EXIT_FAILURE;
    }
  assert (number == TAROT_KING && suit == TAROT_SPADES);
  if (tarot_decompose (TAROT_EXCUSE, &number, &suit) == 0)
    {
      fprintf (stderr, "Impossible: decomposing the excuse is an error.\n");
      return EXIT_FAILURE;
    }
  name = tarot_card_to_string_alloc (card);
  assert (strcmp (name, "KS") == 0);
  free (name);
  card = tarot_card_parse (ks, &end);
  if ((const char *) end == ks)
    {
      fprintf (stderr, "Could not parse '%s' at all.\n", ks);
    }
  else if (*end == '\0')
    {
      printf ("%s parsed successfully\n", ks);
    }
  else
    {
      fprintf (stderr, "Trailing garbage: '%s'\n", end);
    }
  tarot_quit ();
  return EXIT_SUCCESS;
}
